import 'dart:async';
import 'dart:math' as math;
import 'dart:ui' as ui;

import 'package:flutter/widgets.dart';
import 'package:meta/meta.dart';
import 'package:notus_plus/notus.dart';

import '../../zefyr.dart';

/// Provides interface for embedding video into Zefyr editor.
// TODO: allow configuring video sources and related toolbar buttons.
@experimental
abstract class ZefyrVideoDelegate {
  /// Builds video widget for specified video [key].
  ///
  /// The [key] argument contains value which was previously returned from
  Widget buildVideo(BuildContext context, String key);
}

class ZefyrVideo extends StatefulWidget {
  const ZefyrVideo({Key key, @required this.node, @required this.delegate})
      : super(key: key);

  final EmbedNode node;
  final ZefyrVideoDelegate delegate;

  @override
  _ZefyrVideoState createState() => _ZefyrVideoState();
}

class _ZefyrVideoState extends State<ZefyrVideo> {
  String get videoSource {
    EmbedAttribute attribute = widget.node.style.get(NotusAttribute.embed);
    return attribute.value['source'] as String;
  }

  @override
  Widget build(BuildContext context) {
    final theme = ZefyrTheme.of(context);
    final video = widget.delegate.buildVideo(context, videoSource);
    return Padding(
        padding: theme.defaultLineTheme.padding,
        child: video,
      );
  }
}